==> haskell-pcre-heavy-1.0.0.2-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-D8r4lNpVFmLIqF9G0b7Lk
key: pcre-heavy-1.0.0.2-D8r4lNpVFmLIqF9G0b7Lk
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: dbc30271e07f9550fbab14bd5cb47c62
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-D8r4lNpVFmLIqF9G0b7Lk
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0 bytestring-0.10.8.2
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0=8201cf7a2cbd2134b29948f1cf78d17d
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.2-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-ChPK6Ydii97GvZId1woVVR
key: pcre-heavy-1.0.0.2-ChPK6Ydii97GvZId1woVVR
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: a0807273f9525a1e6d85350affced2de
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-ChPK6Ydii97GvZId1woVVR
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0 bytestring-0.10.8.2
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0=8201cf7a2cbd2134b29948f1cf78d17d
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
